==> client-java-api-3.0.0-sources.jar: io/kubernetes/client/models/V1beta1SubjectAccessReviewSpecFluent.java <==
package io.kubernetes.client.models;

import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.kubernetes.client.fluent.Predicate;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface V1beta1SubjectAccessReviewSpecFluent<A extends V1beta1SubjectAccessReviewSpecFluent<A>> extends Fluent<A>{


    public A addToExtra(String key,List<String> value);
    public A addToExtra(Map<String,List<String>> map);
    public A removeFromExtra(String key);
    public A removeFromExtra(Map<String,List<String>> map);
    public Map<String,List<String>> getExtra();
    public A withExtra(Map<String,List<String>> extra);
    public Boolean hasExtra();
    public A addToGroup(int index,String item);
    public A setToGroup(int index,String item);
    public A addToGroup(String... items);
    public A addAllToGroup(Collection<String> items);
    public A removeFromGroup(String... items);
    public A removeAllFromGroup(Collection<String> items);
    public List<String> getGroup();
    public String getGroup(int index);
    public String getFirstGroup();
    public String getLastGroup();
    public String getMatchingGroup(io.kubernetes.client.fluent.Predicate<String> predicate);
    public A withGroup(List<String> group);
    public A withGroup(String... group);
    public Boolean hasGroup();
    
/**
 * This method has been deprecated, please use method buildNonResourceAttributes instead.
 * @return The buildable object.
 */
@Deprecated public V1beta1NonResourceAttributes getNonResourceAttributes();
    public V1beta1NonResourceAttributes buildNonResourceAttributes();
    public A withNonResourceAttributes(V1beta1NonResourceAttributes nonResourceAttributes);
    public Boolean hasNonResourceAttributes();
    public V1beta1SubjectAccessReviewSpecFluent.NonResourceAttributesNested<A> withNewNonResourceAttributes();
    public V1beta1SubjectAccessReviewSpecFluent.NonResourceAttributesNested<A> withNewNonResourceAttributesLike(V1beta1NonResourceAttributes item);
    public V1beta1SubjectAccessReviewSpecFluent.NonResourceAttributesNested<A> editNonResourceAttributes();
    public V1beta1SubjectAccessReviewSpecFluent.NonResourceAttributesNested<A> editOrNewNonResourceAttributes();
    public V1beta1SubjectAccessReviewSpecFluent.NonResourceAttributesNested<A> editOrNewNonResourceAttributesLike(V1beta1NonResourceAttributes item);
    
/**
 * This method has been deprecated, please use method buildResourceAttributes instead.
 * @return The buildable object.
 */
@Deprecated public V1beta1ResourceAttributes getResourceAttributes();
    public V1beta1ResourceAttributes buildResourceAttributes();
    public A withResourceAttributes(V1beta1ResourceAttributes resourceAttributes);
    public Boolean hasResourceAttributes();
    public V1beta1SubjectAccessReviewSpecFluent.ResourceAttributesNested<A> withNewResourceAttributes();
    public V1beta1SubjectAccessReviewSpecFluent.ResourceAttributesNested<A> withNewResourceAttributesLike(V1beta1ResourceAttributes item);
    public V1beta1SubjectAccessReviewSpecFluent.ResourceAttributesNested<A> editResourceAttributes();
    public V1beta1SubjectAccessReviewSpecFluent.ResourceAttributesNested<A> editOrNewResourceAttributes();
    public V1beta1SubjectAccessReviewSpecFluent.ResourceAttributesNested<A> editOrNewResourceAttributesLike(V1beta1ResourceAttributes item);
    public String getUid();
    public A withUid(String uid);
    public Boolean hasUid();
    public String getUser();
    public A withUser(String user);
    public Boolean hasUser();

    public interface NonResourceAttributesNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1beta1NonResourceAttributesFluent<V1beta1SubjectAccessReviewSpecFluent.NonResourceAttributesNested<N>>{

        
    public N and();    public N endNonResourceAttributes();
}
    public interface ResourceAttributesNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1beta1ResourceAttributesFluent<V1beta1SubjectAccessReviewSpecFluent.ResourceAttributesNested<N>>{

        
    public N and();    public N endResourceAttributes();
}


}

==> client-java-api-5.0.0-sources.jar: io/kubernetes/client/models/V1beta1SubjectAccessReviewSpecFluent.java <==
package io.kubernetes.client.models;

import java.lang.StringBuilder;
import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.kubernetes.client.fluent.Predicate;
import java.util.LinkedHashMap;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface V1beta1SubjectAccessReviewSpecFluent<A extends V1beta1SubjectAccessReviewSpecFluent<A>> extends Fluent<A>{


    public A addToExtra(String key,List<String> value);
    public A addToExtra(Map<String,List<String>> map);
    public A removeFromExtra(String key);
    public A removeFromExtra(Map<String,List<String>> map);
    public Map<String,List<String>> getExtra();
    public A withExtra(Map<String,List<String>> extra);
    public Boolean hasExtra();
    public A addToGroup(int index,String item);
    public A setToGroup(int index,String item);
    public A addToGroup(String... items);
    public A addAllToGroup(Collection<String> items);
    public A removeFromGroup(String... items);
    public A removeAllFromGroup(Collection<String> items);
    public List<String> getGroup();
    public String getGroup(int index);
    public String getFirstGroup();
    public String getLastGroup();
    public String getMatchingGroup(io.kubernetes.client.fluent.Predicate<String> predicate);
    public Boolean hasMatchingGroup(io.kubernetes.client.fluent.Predicate<String> predicate);
    public A withGroup(List<String> group);
    public A withGroup(String... group);
    public Boolean hasGroup();
    public A addNewGroup(String arg1);
    public A addNewGroup(StringBuilder arg1);
    public A addNewGroup(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildNonResourceAttributes instead.
 * @return The buildable object.
 */
@Deprecated public V1beta1NonResourceAttributes getNonResourceAttributes();
    public V1beta1NonResourceAttributes buildNonResourceAttributes();
    public A withNonResourceAttributes(V1beta1NonResourceAttributes nonResourceAttributes);
    public Boolean hasNonResourceAttributes();
    public V1beta1SubjectAccessReviewSpecFluent.NonResourceAttributesNested<A> withNewNonResourceAttributes();
    public V1beta1SubjectAccessReviewSpecFluent.NonResourceAttributesNested<A> withNewNonResourceAttributesLike(V1beta1NonResourceAttributes item);
    public V1beta1SubjectAccessReviewSpecFluent.NonResourceAttributesNested<A> editNonResourceAttributes();
    public V1beta1SubjectAccessReviewSpecFluent.NonResourceAttributesNested<A> editOrNewNonResourceAttributes();
    public V1beta1SubjectAccessReviewSpecFluent.NonResourceAttributesNested<A> editOrNewNonResourceAttributesLike(V1beta1NonResourceAttributes item);
    
/**
 * This method has been deprecated, please use method buildResourceAttributes instead.
 * @return The buildable object.
 */
@Deprecated public V1beta1ResourceAttributes getResourceAttributes();
    public V1beta1ResourceAttributes buildResourceAttributes();
    public A withResourceAttributes(V1beta1ResourceAttributes resourceAttributes);
    public Boolean hasResourceAttributes();
    public V1beta1SubjectAccessReviewSpecFluent.ResourceAttributesNested<A> withNewResourceAttributes();
    public V1beta1SubjectAccessReviewSpecFluent.ResourceAttributesNested<A> withNewResourceAttributesLike(V1beta1ResourceAttributes item);
    public V1beta1SubjectAccessReviewSpecFluent.ResourceAttributesNested<A> editResourceAttributes();
    public V1beta1SubjectAccessReviewSpecFluent.ResourceAttributesNested<A> editOrNewResourceAttributes();
    public V1beta1SubjectAccessReviewSpecFluent.ResourceAttributesNested<A> editOrNewResourceAttributesLike(V1beta1ResourceAttributes item);
    public String getUid();
    public A withUid(String uid);
    public Boolean hasUid();
    public A withNewUid(String arg1);
    public A withNewUid(StringBuilder arg1);
    public A withNewUid(StringBuffer arg1);
    public String getUser();
    public A withUser(String user);
    public Boolean hasUser();
    public A withNewUser(String arg1);
    public A withNewUser(StringBuilder arg1);
    public A withNewUser(StringBuffer arg1);

    public interface NonResourceAttributesNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1beta1NonResourceAttributesFluent<V1beta1SubjectAccessReviewSpecFluent.NonResourceAttributesNested<N>>{

        
    public N and();    public N endNonResourceAttributes();
}
    public interface ResourceAttributesNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1beta1ResourceAttributesFluent<V1beta1SubjectAccessReviewSpecFluent.ResourceAttributesNested<N>>{

        
    public N and();    public N endResourceAttributes();
}


}
